@@ -32,6 +32,7 @@
 #include "eel-glib-extensions.h"
 #include "eel-gtk-extensions.h"
 #include "eel-stock-dialogs.h"
+#include "eel-i18n.h"
 #include <X11/Xatom.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -40,7 +41,6 @@
 #include <libart_lgpl/art_rect.h>
 #include <libart_lgpl/art_rgb.h>
 #include <libgnome/gnome-exec.h>
-#include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomeui/gnome-file-entry.h>
 #include <libgnomeui/gnome-icon-list.h>
@@ -50,6 +50,7 @@
 #include <limits.h>
 #include <signal.h>
 #include <stdio.h>
+#include <stdarg.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
@@ -587,6 +588,18 @@ icon_selected (IconSelectionData *selection_data)
 	
 	gnome_icon_selection_stop_loading (GNOME_ICON_SELECTION (selection_data->icon_selection));
 
+	/* Hide the dialog now, so the user can't press the buttons multiple
+	   times. */
+	gtk_widget_hide (selection_data->dialog);
+
+	/* If we've already acted on the dialog, just return. */
+	if (selection_data->dismissed)
+		return;
+
+	/* Set the flag to indicate we've acted on the dialog and are about
+	   to destroy it. */
+	selection_data->dismissed = TRUE;
+
 	entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (selection_data->file_entry));
 	icon_path = gtk_entry_get_text (GTK_ENTRY (entry));
 	
@@ -606,7 +619,6 @@ icon_selected (IconSelectionData *selection_data)
 	/* We have to get rid of the icon selection dialog, but we can't do it now, since the
 	 * file entry might still need it. Do it when the next idle rolls around
 	 */ 
-	selection_data->dismissed = TRUE;
 	gtk_idle_add (widget_destroy_callback, selection_data);
 }
 
@@ -958,3 +970,61 @@ eel_bonobo_pbclient_set_value_async (Bonobo_PropertyBag  bag,
 		CORBA_exception_free (&ev);
 }
 
+/**
+ * eel_glade_get_file:
+ * @filename: the XML file name.
+ * @root: the widget node in @fname to start building from (or %NULL)
+ * @domain: the translation domain for the XML file (or %NULL for default)
+ * @first_required_widget: the name of the first widget we require
+ * @: NULL terminated list of name, GtkWidget ** pairs.
+ * 
+ * Loads and parses the glade file, returns widget pointers for the names,
+ * ensures that all the names are found.
+ * 
+ * Return value: the XML file, or NULL.
+ **/
+GladeXML *
+eel_glade_get_file (const char *filename,
+		    const char *root,
+		    const char *domain,
+		    const char *first_required_widget, ...)
+{
+	va_list     args;
+	GladeXML   *gui;
+	const char *name;
+	GtkWidget **widget_ptr;
+	GList      *ptrs, *l;
+
+	va_start (args, first_required_widget);
+
+	if (!(gui = glade_xml_new (filename, root, domain))) {
+		g_warning ("Couldn't find necessary glade file '%s'", filename);
+		va_end (args);
+		return NULL;
+	}
+
+	ptrs = NULL;
+	for (name = first_required_widget; name; name = va_arg (args, char *)) {
+		widget_ptr = va_arg (args, void *);
+		
+		*widget_ptr = glade_xml_get_widget (gui, name);
+
+		if (!*widget_ptr) {
+			g_warning ("Glade file '%s' is missing widget '%s', aborting",
+				   filename, name);
+			
+			for (l = ptrs; l; l = l->next) {
+				*((gpointer *)l->data) = NULL;
+			}
+			g_list_free (ptrs);
+			g_object_unref (gui);
+			return NULL;
+		} else {
+			ptrs = g_list_prepend (ptrs, widget_ptr);
+		}
+	}
+
+	va_end (args);
+
+	return gui;
+}
