@@ -27,7 +27,7 @@
 */
 
 #include <config.h>
-#include <libgnome/gnome-i18n.h>
+#include "eel-i18n.h"
 #include "eel-vfs-extensions.h"
 #include "eel-lib-self-check-functions.h"
 
@@ -1633,6 +1633,53 @@ eel_copy_uri_simple ( const char *source_uri, const char *dest_uri)
 	return  result;
 }
 
+
+gboolean
+eel_vfs_has_capability_uri (GnomeVFSURI     *uri,
+			    EelVfsCapability capability)
+{
+	gboolean ret;
+	const char *scheme;
+
+	g_return_val_if_fail (uri != NULL, FALSE);
+
+	scheme = gnome_vfs_uri_get_scheme (uri);
+
+	switch (capability) {
+	case EEL_VFS_CAPABILITY_SAFE_TO_EXECUTE:
+		ret = gnome_vfs_uri_is_local (uri) ||
+			!strcmp (scheme, "file");
+		break;
+	case EEL_VFS_CAPABILITY_IS_REMOTE_AND_SLOW:
+		ret = !(gnome_vfs_uri_is_local (uri) ||
+			!strcmp (scheme, "file"));
+		break;
+	default:
+		ret = FALSE;
+		g_assert_not_reached ();
+	}
+
+	return ret;
+}
+
+gboolean
+eel_vfs_has_capability (const char       *text_uri,
+			EelVfsCapability  capability)
+{
+	gboolean ret;
+	GnomeVFSURI *uri;
+	
+	g_return_val_if_fail (text_uri != NULL, FALSE);
+
+	uri = gnome_vfs_uri_new (text_uri);
+
+	ret = eel_vfs_has_capability_uri (uri, capability);
+	
+	gnome_vfs_uri_unref (uri);
+
+	return ret;
+}
+
 #if !defined (EEL_OMIT_SELF_CHECK)
 
 void
